#!/bin/sh
# This is update 008 for teTeX-0.4.
#
# What this script does:
#
# Update LaTeX to version: LaTeX2e <1996/12/01> patch level 1
# changed files in $TEXMF/tex/latex:
#   tex/latex/base/doc.sty tex/latex/base/ltpatch.ltx
#   tex/latex/base/shortvrb.sty tex/latex/graphics/dvipdf.def
#   tex/latex/tools/tabularx.sty
#
# This script won't ask any question and overwrite your files in $TEXMF.
# So, if you want to be careful, make a backup first.

# To install it, just run it with a bourne shell, e.g.
#   sh ./update-008.sh

last_line=115
this_update=008

case $0 in
  /*) this_script=$0 ;;
  *)  this_script=`pwd`/$0 ;;
esac

force=false
for i
do
  case "x$i" in
    x-f) force=true;;
  esac
done

: ${TEXMF=`kpsetool -v '$TEXMF'`}
test ! -z "$TEXMF" || { echo '$TEXMF: variable is unset.'; exit 1; }
test -d "$TEXMF" || { echo "$TEXMF: no such directory."; exit 1; }
test -w "$TEXMF" || { echo "$TEXMF: no write permission."; exit 1; }


trap 'echo "Cleaning up ..."; cd /; rm -rf $tmp; trap 0; echo "All done!"; exit 0' 0 1 2 15

tmp=${TMP-/tmp}/inst.tmp.$$
test -d $tmp || mkdir $tmp
cd $tmp || { echo "$tmp: cannot change to that directory"; exit 1; }

if test -f $TEXMF/updates.dat; then

  if grep 'Main version number: teTeX-0\.4' $TEXMF/updates.dat >/dev/null; then
    :
  else
    echo 'This update requires teTeX-0.4.'
    exit 1
  fi

  for num in 001 002 003 004 005 006 007; do
    if grep "update $num for teTeX-0\.4" $TEXMF/updates.dat >/dev/null; then
      :
    else
      echo "This update requires 'update $num for teTeX-0.4' to be installed."
      exit 1
    fi
  done

  if grep "update $this_update for teTeX-0\.4" $TEXMF/updates.dat >/dev/null; then
    if $force; then
      :
    else
      echo "Error: update $this_update for teTeX-0.4 already installed."
      echo 'To force reinstallation, call this script with -f flag.'
      exit 1
    fi
  fi

else
  echo 'This update requires teTeX-0.4 with update 001 - 007 installed.'
  exit 1
fi

umask 022

echo "Running uudecode to extract update$this_update.tar.gz ..."
tail +$last_line $this_script | uudecode

test -f update$this_update.tar.gz || {
  echo "uudecode failed. Aborting."; exit
}

echo "Decompressing update$this_update.tar.gz ..."
gzip -d update$this_update.tar.gz

test -f update$this_update.tar || {
  echo "decompression failed. Aborting."; exit
}

echo "Unpacking update$this_update.tar ..."
tar xf update$this_update.tar

if test -d $TEXMF/tex/latex; then
  HAS_LATEX=true
  (umask 0; cd $TEXMF; tar xvf -) <latex-base.tar
else
  HAS_LATEX=false
  echo "You don't seem to have LaTeX in $TEXMF/tex/latex."
  echo "Theerefore, none of your files need to be updated by this update."
fi | sed "s@^@$TEXMF/@"

$HAS_LATEX && { cd $TEXMF/web2c; initex latex.ltx; }

grep "update $this_update for teTeX-0\.4" $TEXMF/updates.dat >/dev/null ||
  echo "  update $this_update for teTeX-0.4" >> $TEXMF/updates.dat

exit 0


begin 644 update008.tar.gz
M'XL(`,(@&#,``^P[>7_;-I;YVY\"'8_;)'4<RT[L7L[2=9S&N_$QCM-.-D@F
M%`5)'%.D2I`^2BF??=][.`A0E.RD37^[OZW:R";P`+S[`KWV\,YG_[!'Z]N/
M'[,[##_KC9_Z@6UMKF^M;ZQO=![!\W9G:^L.>_SY4;MSIY1%F#-V)\^R8A'<
M3?/_1S])6(BK!]U0BC7@P^<YH[.^OO7HT1SY=[;7X6/E#U\PUMG>6+_#UC\/
M.O[G_[G\U_Z7V?_ZXVVR_^W-O^S_S_B`]7]V#?@$^6]M_N7__Y0/RI]BP&?4
M@H^6?P?@_[+_/^53RQ]S@,^C!+>7?V=[^_$CC/];V]M_R?_/^#3DW\NB-5E<
M_[%G+,S_V/:CK:U-(_^M1QMH_YN;Z/__RO\^_V=E96EEA9T-8\G@_WZ<"/9>
M*\%7JS@U$*G(04%Z[#(NAJP8"@;SLLCC,2N+.(F+Z[4ELXM@61X/XC1,F,S*
M/!*THV27(A??:2C<O5=<,7:7-LS&19RE\COV?AQ&Y^%`?'4/H5RL0@<)W&_-
M`.QEXVLX;UBPSK??;N+7(_QZC%];^+5MT'H1GHE_;K*3//NWB`H6ICWX=\WB
MM!=?Q+T2\`W+8ICEDB6QQ'-$(L7E$-#&'>(4Z-;LL8<_RW+6+W-@2,XBBTB<
M]K-\%")-JW1,E,$91"*#&3;*>G$_C@@`=T&07HSL[)9JD12"N$RR2,0@3-:*
MJV+5XISY)^(F:5;$$;"Y%<\S,X*L'(=YP;(^'4`\V1!,7@/%(X)_<,L/PC*U
MLUJ->ULR@'V$B6##;(S$A,"7`O0G25A7L%**?IFLJCT`G/UR</;\^-49VSUZ
MS7[9/3W=/3I[_3VI6P:SXD*HS>+1.(E1#\,\#],".-%7>QSNG^X]AT6[/QZ\
M.#A[#3K(GAV<'>V_?,F>'9^R77:R>WIVL/?JQ>XI.WEU>G+\<M]RAY$<19[#
M=R[&65Y(%%DD\C1.!^S5$>[\T_Y3=B%R25(D[AF6IIG:9)3E1&C*LE2P:P$N
M)4MZ2IC=<B!1A,Z9)XD`;PNF@**#<W\MA2Q8.>Z!CL/.>38"+@%#<U#6Y'H-
M%N3Q*,ROU6I77Y#QQ3#/RH&RS;VSW2,6YM$POA#2GHC_#@Y/CD]A]HSM'9^\
M/CWXZ?D9.SH&ONQ_9T!>9R6L%3C,=E^\./X%Z"XR1[`.Y6$"E*XU5X9)DEV"
MC.:M*M,>*"\B:NW"Z`<9FJ]%1380I.WD*6!O:QC63D'11F$:]X%_'H\/^NP:
M<`(&"N`$2"6Y!I<T$EKYI=F&>(T30,TJ(`4Z%L;I%R[C3D0^BJ74S!Z@[BD*
MT08=VF`D3)5UTK-"&G>(0-PY(`"FWP>7DA8L#0$5M&C<!D)0-HI_4V;?$U$2
MYJ'R&+'B#NU!AV6@4?F%@DR%Z)$Z`J$Y@$(@2Q+M><9Y!GX-T43F`H#:`JB[
MKOVXXYJTO?H^QS+S.<@4]'\5%(.=[)\>'KQ\>7!\U."&\=%H?K[XB0?*\0&H
M-B3?CI1>Q&!\-H`@BV;TJZ&9$5C<0+0X/?QW>/STX-G!WNX9XKK[]&=7T[5Z
M7`+V31'HK5;19<'O7;1,`!F%YT")$H-R/,@P)\K=E?>4-ET.XVA(#B^4*(A>
M&8D>V/`KB1M8'2#'C6J`88%$B'O?C07L@YI!#+O6@M(3WRO\R).*5)8J/!D9
M^]%%&O<"-L0RX/IE'A<%^%((:RE1KU5&R2<5EV`MRB_I``&S:2_,>R9",!*#
M!*^<0"A*9*9QL#KJX`""=G@#J("M*62TEF`HLZ#67BQ?D3'*2##^6TP\(2,V
M44B:FS)`/"83LVK7PI&N`P#NW9QF\4"^@VS@W)Z1=%/,JZP(SS$T1*B/!?G_
MK%M;I6]4UI9F):?$1OX"]X"H"-D'DB/#O@!*8*"%!(]XVHT$@;X`M52KFUJ8
M76(Z4<9%V(7]B*I5MA:GUE\IIY`6>:8\JQ:.MD['0=)V#A.^K^T$]]`J@5N!
M\[2'`S8B''5IERQW?'=<ZX%<1;50@LB`8NV(K,`MNM)):)1JR!;I2&1;CUP%
M(`4HA%U0?<\M+/$C=)R0^SRC3*W2>=#T#>:/#SL;#]<[;Y<8/U$N5)ZHM+2"
MO'6ZQ!A";3]<!ZC'[**S]NUO,,9>&G1I+TQQRQ&8N&*ESFO9W6>'\;VWB`+?
M&X*+CPJ1GX%HB(6L>C4>B_Q!A/8''[[+?^1[_"G?Y\_X3_PY/^#_R?^+O^"'
M_(@?\Q/^#W[*7_(S_HK_S'_A_^2O^7^K[.`%.&MGGY!W><1[7/`^'_`AC_F_
M^3E/^(BG/.-C_BO/N>0%+_D%O^17_)K_IO9Y"GX8_+'^\'7>X1M\DS_BC_D6
MW^;?\&\5W/X5!"R5\2+<%P3^-"N!,/9KF8$A,OXW&GP>RB&[FY:CKLCO,;ZL
MS\D@:N7VG+_3#XBY$<9)/;A"/W9'P"&)-DJ#7ZKUNQ'%F$C!\Z]H\H7H%YCL
MBI1`[]+@*67H9I3?T^O!M^6Q/-='W5?G)Z4E'0:_IA][V6@4UH,Z@SV,4P>6
M/U#KL]AB#X-K].-EED"M86#Y0[5^+TN(<WKT.P4J1G%D)_CWFB@I59))@S]H
M_O\*Y4LMIQWZ\1-87D&9%D+S)S3X#\PR44R02IXS_A_F_-$(N!UC#50P'M3\
MZX*.G@MDZAL:_!$>98)"I).X6J^X:F#Y6\6J.`<3Z"?BBD#?T>`K#/(RPE09
M!_^EUO^4AQ>._-[[YRO0B@9_%CG4.8!G%_6%3YKG(RR?$NA9G/1$S=0/4UU\
M:F.F&O<K=)CH92DA4I:[(?RZ\N[>/:@CO_GV`5H]>P;9SCD(',)HT@VCX2KE
MI`0I(6Y0$.BM+?$@[F-"TX]3T:M&891G0906TVI:<0'1(1V7Q72)@T>/LIYX
MS]^]V]WI/%KBL((3-`Y77"^$W]'%\#ZH;324X$TP^O#@(NN*:WP4DN:O:OBI
MLQ<-5"L$4F1C*<:,'YI#SFB`YH*N@+P+C&,,\2^!ZHJ#]X9@"?GPM1XBN+@?
MQ&D2=D7"(5FX$!<0GL"WQ.J`/+[`Q!P6A[D\C^&LWP)8`]G#F[<*!X54'T(%
M/28@:`3D09%A,@*/H)V`"7BNWD4(A5@-0F@?`&/U6L5XG,%#X,28YLP3Q(-$
M;=T':QX.DE(QLIN`%(,$A-,'PQ&,>`7P%=!6SRVQ19]9VA?`UIL6>2EX$,!A
M-RS1'.?@142.*_7`E"A`R>.@U"PL>"^#_X,4',Q`,@[)7A<<\D@-!"@1%S+`
M7%85*O`HQP*-7^TU2+)NF/``LD%<10SR)D9Q&H_!@NJ9N(^:A.@$R/\K11G'
M@N&:N*J7&G%&P9Z&/\KPH"8G.(2#<<4!/0>.\6&KEDQ79I9'0Q&=!R"9,A%J
MF@L2<XU1"XA68*"N"$#+I,Q%'\P(^!#W?;T@=0$SKBUU!@?BRGBD3V`(/8`2
M':S!#FK5:].=&M%9ZAQ):"NT@FANDO:,-;;,1@DD6RZAGLLB0WN6H<M"#-#F
ML78$E>I2PX\V)#Y8R(K+$0BF3:TY-GP`!%`"=H'S@H5AF;2@Y:PIBMM`C7JW
M@2K'"Z"(QZ0AK50AX@;OVQ!`"_KA"&J1Q300($0,*.L6DZ$`A^%8+"9$"4"1
M0VH%\:8AU]VDN+UH7>`%TF6?)F!V6QFSVXJ96)`L!FP3MD_GQ\J;?83(V4=(
MG7F"OXFNA>)!HAV-P"!0!^&=6MF59W-]HU$1=TPJSGV<?^/B:HP54A^B&>^7
M18F=AL(;3<65/Q`-@[&J`I1&.][8GJ)0?@K([R&*API#W\%+0D6G1`O`,#8[
M9WASC;!"L(9=!DO#+`S>-!!!D4=DS;)`;1:F@T18XFKFT_ARIW(X1=R!LV@*
M@"E9(YX[>>0/'&K*^`(P&VC4"!SSFJL?YF(2C"$["D01&=/P"-#(F0T-[`\M
MR"'J9AZ6&*5P*3/3.F0BM[ZN$=,9"FU7BUBA#'@A](./@K[?#HTW?JWP#^?`
M8\TSL^`F)/JQ_5\-(-`\T7W8L;)+(C/TGC^!1RSGL9JOE!#L*<N=#U!/V$=2
M23Q&:7>UW)FZ1RE<30XV*,.\%R20:"1U"@8<@-K<G7L"R9II;:AMGXIQ,?1<
M)I(WG473X3$A2L91HT:/*I.Q6+$6M!1.[!9(*1[KY*CIXUR$&R6(TF\KB"<[
MOA&YLE_N//EX.D9S"=GY:$)J7]TLI+04:IL#-Q9E)58/5<L9TQK`0ZF9!ZH,
MV2:X*CG2O(`"->M!*5$,J<24?^<)N1N.0[)/"IC3R-^G)O905>JMJ@A<\7ZR
M\[>-C:U=Y@Q]"4/K&UL*W[H(K&O7F6*6[;#-<<'0T[#.V@;\.J(&36=<T":]
M>"12KY3D4A1%=AGW0+.=\8KG(QW5993'XT+B_<#Z.F>85E$W5?0K6P7<G[H5
M.Y=^.>ZZ7)1I)*FY[981]U%Z>GR'>16&HY]?[-2_8_?CW;M==J"O?:6(](6:
MR`4;E5"'8\N]>T,M2WM@.UXXG3QL$<FUFQ?.\6>3':K"[?.;'31H9^#M#B\N
M`V=%M=/9<.:G\.C,KOBSS%BI,\:MY7ZQHIQTVG/%LT2=R2-PPJR?X36EI.8Q
MK,'K?U+YV+2^V<21Y>1[M53=LN,B]5S6-R5X>2)D!*D:7DFIUNX:8[\(O)S$
M?A/=CQ7JP'Q`S6&UB2QS8%V*5W7=:]WZSK'!,_'QGTY6Z:X\5)O`G%H_-%=S
M<<KD."XL2IHNBX[NC/=*VMT2X=&MADB7Z.!5A<6DOC(TR+.)BYI:9^[WQ97`
MEFQO%:G6=QTA`V^&SK$'(Q=QGJ6XRYI:J%3(D]4$G>_$L:'E3HM0IV^6.Q,8
M>6-'WKZ=+WWW&#!6WT()D3.Z?W458>*!3?!"D&Y118%7-"#;)!MDI5Q5Z_&6
M68M%$-$RP1:5=_-;X&UR&N+UDQ&U\V)$3[/D*"OT!1&I!';Y\&PT9ZWXYEV/
MF]D)W#1&,F%H5HJY\B;NWI]E[_TY_-7\ZXHH1*M`G"?&,B?ZEE:R(39ZNT*@
M=^D)EF34R]4<B[`-G5)O,]3V!D9%?F55>[0TN_1,%UQ5-+2V0J!:%8$Y(<M#
MNEM3M@HA`,U!%M<)F0A>AL+2^2RSH;2=7M<CHZ>B.D1@H.@*"B*5VR(,NG(\
M#*/S)7L6[0WAYER<Y/%%6(@7$(3`2NTF`>TR]7=6@QA[+7J^1^:J+49=KCP<
M#$0/>V4<SD@+'ST(SS/M)?Y2]0)?2?!9&`6O*(H'0F'/XT&:Y4+UG!N8[:<7
MK10OIA8S%TL;;-$D%X9^)[&(UR)28?YF0G-TL5+8XRAE2$0Z@(S!#HY+.:S6
MQ\44R_'9:<HOJF_&4!I5\^,DK^VS2ZEGQ:>:*::I6]VF58_W`QJ^2;B3""^X
M4H"G*[.#F^^8,4QW_C`\`NF>A<0&-;7UG8*Z1L"6E>E"J\KM@A)#?>-0MU3G
MWRUX-P<&VKT_F'-]8,^H5[G-?#A'C,;R,M0]6?=BP4SQ83>[JJ98%YJAUDN!
MN3<`Y$)T-:W*=.KO.%<"M[T06'P=X*DIIE^X($L'IA7@((`F&O>O&$21NAH.
M@#B4OVAM3[=\[-*=Y0ZP1]?+CO*#D8LDO(*C1N1BD)-*`1R_DY9)HE2`=W5/
MZM;W(]B15!F_`@E$E@3JU<";KTX8EDY8]8)=2%R-!N(95-/:%)3NR-%Y.D<*
ME+M4'%RJ&1`(FJC<XG#N.JZ`ITM+?AN@UA15N]:;&V(K'T25?>_>'58N$CR@
MM\;U"L^[GJD4&SB49JKNH844X?'R7IAL%W[!4(PGH>\=1NBF&WTCQ270,,+6
M*"1HB$Z#6-TO@=$&21Y?//1UQ\,CXB"AMW5,7M^.O4:4#J)R3G%C]C@$<)HB
M(*L/+@)-K^ZH8H6*]AZ_?L"O)_BUBE]?X=<#O="J\US>+'FYAJ;8Z2X!(!F4
MF:F1-2+`@SYX8?U<Y"GZ1RPKWF-<=3H)IF2J6RSPZ\ZZ<Q==-?!QXA[Z%PH*
MS10!]L)[J@`[*+I%JR[@;-K[>W<U_6'R;H0K32UWEC<JI[6M+L]5V#*]!_>&
MC0OJ%P&KL+\!0!@RH<R@'']Y0ZF,8L6YH*N[972<=-NY;%(4YWI]R3I%"A2A
M]:C$[*!FL0;,LK%IX2F()TZ8(MS4/I79CR(1XE>"FZVO9_7N5*[G$'5"TS6>
M@SN_`,Y`J<?Q#TC(:T"$O,GC^T@@^1#%Y=3D:74KS=$IW4BC%K4S08T%?=/@
MTVD-F!('[:.4DU!<L0"4,I)DCT!HY@;;B5P-4,@:'4"3<3C"?JNDJ3"I>X0+
M+\%KS$QR>AC&J<Y.-Z:`0C<7X;F!>9I!D6AGZXONECWJ)-??1C-M$6ZV?>EG
MQ'1[HSM4_EVSF7(,U$(VNGC:BA@SV:#MX&V;#E[=O]O`_IW7G?2%1F]&5&1@
M_@0J*BFYEW+JTAM\()O.7I3.UDO-[;W)WWT$E3[M!^@2:&;[1=MJ]6QNJ8=O
MV*[]?L+OBIOBB5I>&`MT$&J+.&4C/M,8ONOHW!:HS0/50@MPP^J#K=FXL,<H
MM\3X%;E:A82WREA@QQB$=M]>;[Q&T8L6JA9K[2BJBLQ[.:2JFRI\8I(1-D'M
MUZ4;83]I+7IAW'1'G,[P^TD+21,;S&&1`XPG36;Y-H%?4Q5_W";&K,0JSF=?
M^VBB2AK$*'MIZU5@-`BATL4GV]_W7RVI9D^F@TF`%E7]?EH+^6J\$..`2@Y9
M4AT)<8X6ZS\W<:_B5%S`V(M_ZV22:`V`IV)9,7-[J5;)R[B(AMY+0S/UC'Y1
M2%_FF=MB%QLZR1VH;XN?QA)?^-W3S)%5W2=Q%U!&8KL1FEO[Z6V6FFO`V<]-
M"-CCF@>[O,%"#S2W#H?(!Q8:2VWP,_6#J7NE.LSR0LF>-7E*JE'/H[N:E^!]
MN=/I."[FRQWWHN6]=09*H([3J<DRBE)].6VX#*UG:58$>#%2]HR><?V2O7K=
MC1I'YHIW1HC&Y<W(B&E"O;U,*@\J91@,?GF.5;0=ASV2()9!V+;(30\:1RB'
M5:\VSUX*U,0*>]+.>?3H5_O8%0!0K[-QJQ54E\SV#II8Z\P<7Q;^$=__I22G
MK>706"CT0GIU>/'*F;7>NQ'Z-?4%JVN"F[&)YK#/,?^?9X"I#MVB17D;S_41
M,WX.DKBZ.K$WLN[@'V7B^GX:@B9JDLF172-W(93B^V0LS3/`]BQ?!QJ5Z6H5
M;NQ8YQ1J-7.X[.33;H;0WK5NJ3*9*LD+9<IN/>F.UXF2U]2&Y+M79,$PR\XY
MP1F2J2&PW%F=NAO6P%2DHD;7;H]>G<5Q79L7V;F<W7.IY9AYR=]D9WUEJ;5'
M[4NG<O,3Q6<]`B4QWIZF+D`+-)_XXEJ=5A,@9C*#ZM3+;:@?X)U#;%G1'=@X
M#0*H,.&_Y8WEY4UZ-G[VJKE0E5+>?3VMW[!,-J`TWDRAU*TK.H>IBC+U0+73
MDJ[3'\@XX/:Y^J(%FM[1<*#M<_6D!5JDX/H=:/M<35J@32/*6>`.55]/;8;G
M&AIZI#H1T4%'!4:/B<$@ZW:3VW6"&;.NTN'?DC=%R-7LNN\A6R_WJ-*&5Z<W
M'CFVV/X\)"TDZM:+B:#;+YK#GT]`^=.66Y5CH[#M9?T:LI%SMC0O%HAE_K[^
MYU-8;\*VO1M0B0N$V%NS@=UUFB'W;HML._.4VZZ<#>5WCA_`?!(D7EAL,3NU
M&[DGTYYSV%[?_WI,GV\#?J;-'"[?QEQUACQ7U1Q.E(C9/+3;-,5EFB?^5E:Y
M#/*$-H/"'RR-.71!$:0IPEYT"Q4JRE.44UDF-7=\GV6Y?FO]O[70YBRW2TP6
M9@>:+KD9A?Q47L<A?[#1*]!$JEK@4Q1O#LY56T2QMP7F&;)'BHL-,AJ%A::C
M,4H)2C.^S"-#'US5!\^+"'.#8I/":4,4+<U$I[Q!V]"]1&>TLN6<4Q?5F<)Q
MTL/T61,WL]C4QG/TU7N1OEVRGT2XM\@]P_V]P9OF;;B^9G165"M3IR&$[SH%
MHS(I\,]XE_A!_UF<B/W_:>])F]LXKMS/_!5MPRI)+!(F0%*R'5$>B;(5;46V
M5E1B5P2EA&-(C(TK&("'IJ#?ON_J[M<]0Y`$:>]6!5.)1?3YNOOU\>YS>+OF
MA4U&)TN`&D'1R_DW%N"WZ;_GV32U9NFVXI++U;#VK5)_I>E_G2FSXRCEP'RS
M(PJS+-OK)E3B<#R8#T=H;1RG')C=C=*X#8J0H`TMK8,'?681"E%*5*^D2KZ(
M&GXOA`H<I8/QR3S]\-[!^L')2RCE37LZS)D`18$/H'+O'/^(A!?WI%]2Z'*]
M(H.8R??6[&*2CN>SXK`]NC\SL!-Z1J^8V=YFC3V4$X_0A<#`$(AFT+Y`AT79
M,8,U2J&[O#V]J"^LZ,^.'>XG@&<VAB*\Y*0A<C;NTIAU)K,"+7^)\_-T,B6[
M&V97VS2SN]^:L,2OY=HJ39_LN9O,F(4>Q3QN``"PA[+%_R#LI)!!#F](08?(
M:P#?$Z_<LX`3O"^86-/0!EI9\>D4%EU8&5Q%*RW1C-XL^"BK,JM$A>?.>-:7
M(I>7_(G\%^3&NE.!/9/-VH.L:Z;I<4J^;U`Y$4=?KDPNQ<1/R!0G&+V%C$X,
M;(SI!;D_$K%/CY0>T9M47FZ%O.6@@*XGO55QG2K-<L,/2Y#ZA2@-5S139:#J
M5609R*FXR+D#0"H&>ZD&$<YP5?DJD/V\NYEF;=M2R8IKT.\5>V9Y/,943W]X
M)3+CA>]ZBS;V)S-=F&SD=YR]@LIT*FIA'3*N$)WQH`^EL7:PK:M$QH&L52,;
MO<!J+53/%:AW48'Q7E`VGW>XJ*W4(AVF=+/`7A;ETI=7:%94()R@?`;FE/]N
M[)1%P+NZMG]DI#ANN$;QG]9HC&A!$FY4)F+VVXQ+P*&$#BA(YP#PM?X(@>SG
MN:GC?Q=B8@Z'*O5K&E@K;.0:;4`I6V?"W<Y'V.YG"X?5[-O?V6$Q;"38]XC,
M%3['UQ>UO1FHY9#N3OV;])SU*;YJ;;7.LEXZ0R\81<LL6EM?E9[:1`!:40BR
MS!!2.5=(9;:\$9A*X3KT-U::I>>S;.9K.'&S/!`3\G>1%*W?QAWRZ04K7G&N
M:J4V7UW$;LX\DA3)BTKMXB1OXZ'T*0U%1*U0P=8T=H2E*P]1FENNPJTG86>D
M!U3;98:AT'-I+ZEF0<,8Z,9'(LV1@5?3^\2(C#2'0LGE\NJ$&M<J>3/V1XN]
M-`T\DW]IZ>NJ>J[*18NGZ(\8<375>"V>340PK@#KS9AL5SH>P4^Q(TQM=Z'5
MDKR:7\1VB'78)%DA0_&2_Q9-H+?P^)OV#GG#D%:`W0B*YG@I20'944ZLH#QL
MH8#XB!,/3+.2_BA3'Q:V1:"R$E(@4>O5\_S>[7=-G:@AV<>V3;H)A;*$0+EZ
M2+C&JQ`8-R`Q0B*C/!$.D!L.7EY8*Y,7KKL*"F/Y=F$DCP=2:'GM)14OHU!*
MC05$2KDK3Z<4O)G,7S.8`UC7Y21+J?2UZE=<\,%:+5CO)TA3K][PLC]T5W-\
MW9\,\LH)+%WX]OQP5SX=`:1UW7HVR,>OT.[.N=43-J!;]Z/9>/+#*>3":3^X
MJ`6$);%J?D2OHBGJFE9"PQ8-5LFH;"_$RE]*!ZD2`50U&$`9:F&+C087K-]'
MSJ\5I$N&$T!40W&D=26F\0]GDT<JRMV!2->;(]P+_(^]%D6W>Z+?-TQG;2T%
M5Q4OJ0;]XN_>.*%B^-NX7_)FW7;\S5X&@T]Q[/A8VD;/:`NVYQ`^;L:.3_"U
M.TQF[;)=`*:2"K)_!*OZUA;]*]L03-?77UES]):R`=`:@B*K%V)$0/5OJRH`
M8_V*?))TK5H%_4V6,9SGYD8_?Z`0E/):"/R[POF';IDVX2M<>X\7@<["S5S'
M$79#8P6+)Y3=N:F:(KS?X<4_8(+-'O.Z>RAED-=U/![/1FC)"J,9Y1?#SGA@
M"IOHSR0TEQ-G!2I;::_36QN[/1[AF5=8Z@N*`*T#J-#_%RJ4]R5_\1718KY]
MMZND$219Z(3PY'H#;J31.'/.Y?S>EKX:0%XQJ5?9XZ*F[HG@LE7W)+P8$C=[
MQE^1K#D#QQW>:=Z?1`)G`#F-0`I&550/OQ;:`!,C!`U;"\J?L"@)73_^GIO8
M>/+*R:8#($%/Y$#;C7OMBX4D<8/>*9DDL^/\PI4BS"A1FY,\\<#)'8^XK=,/
M\!?YWW9W"U)J1Z@+^`]E!10H9\#N$J<)W:Z7(3I7"LK$!2A$;.ETVD$G_<5K
MM$%>^.L=M6H2$46HU%A)A76/EW5)"CC*'&>AGYG!4I34JTW9G$D0V-KF^,GG
MVS-R+.%1UX+8K@+Q<["&GUG6Y32N(]4DZ:G2OLB[T@HF5^YPF$;3'DS3=N_"
M^B5S%KYH0G\W*WL9$`5WTJ-%-FW["H%ZPXIU+H]R6>>ZCHD7P2RM:C1*BKV.
MZ_2@I=2]JW"F&FNJT:82<98@C_[].2B_#)?\>>!MI0+UQ6!1K&:6:8D`ZQ6N
M%/I6MA"&VFRQAD$3O2I@>\QMAWOM^@HXAJT2%8EOA>=JZUM4K,"2`*X3KW7&
M"=X<M'1F%"H37T7F6@TZAE9%>R[/:)-4Y,'Q@!3T=D#\NO$O2<8]Q+F/D.@N
M(<O*ZHV]UBL9Y#+$Y]R,'8T>&1>(,-9?NP2B?LA>`8"O5`6(!<5-A)H3F=OP
MU>)N$C8EMD*^S<U-<T2J[2C!\+T'%\_E&)9?P,/^?(M=<<#_QIU\C(>.@787
M82/ED^]ZD$1'Y:JP1,U8K1%-U13Z9)(C@B7F9&?WR7-&-:E4!%:D<J!1"<@\
MT"(*-=(K/B4C<)4XW`R;#)#_^GX;':(8"\<7EU1*70GKI[Z3TNM4C:VR[K6A
MC-7DHQGPW:C;>4DOFHA4(SFTHYBT<_3D<TFYI9,9*=O+$?P#F3_3&>PZ04\S
MW%$EPCW@-XX=Y).GT80^#`CHXIV-+=*=3]$+#GK$$1_Y&"@B38<Y(CTLS-D4
MWNKU?_WKOP-R]]WTPKI0:K/DM#NS@43J@3K]1O2'O=8MI(S%GKEHTU5G.O&`
M9&R^O!^A*J\2I3SN$IK*H_DPY$1$X%A;AQ(+5EL\E5PHJTV9C+QK2QU3(-1A
MQSQ*%AX+"3NX=(+1(2*7DL$CXZ#1V+"/_:@6#HUE06GO,Z44(15TKK*P)+HP
MY5]Z=:^SY4*&3+`M!"1#[3KLN+3&-?JXSCXI]SJ?`#(OU0IERH!0W$Z[[P3C
M55PV1YSIY]+"Z=FV_K8+.6OQRGNQDECO<0`2N\`5_=]%8`H&\@XB4W!#UPA-
MP5FWB$TA/:T>G()S;Q&=0AI8/3P%_W&+^!1&VETY0`57N46$"@O!RB$JC)K;
ME6)4&(%VY2`5,01+HU1HTAMOG7XZF.@#HSCR,<S,LZ/#5Z^TAS\,>^-.(KQ$
M@\/H%3E0L^0/G2AL@X>QH%".P&<9!^LAI^"`=WB_*J?(@28/"H;T;W9[Q,>.
M]2!`&RKM1265_V2;?C:U]E'(/:-8/F>>CLT``7H9($P+U:[2EG2818)CIQY+
MV:3J4Y;?%"W>YH&C@\6""58$/M!'Q2O=RJCYGI4ZHMXPM/JM50=_U;"KBI5Z
M+<V+E;4XQVR7=URY*E?W:+M1@E<_/=BJ=@N!CYR`OQ>$:V!=85)J`*JC.R/?
MM:ZLO,Q$']+7JG2XV@+D[F3=0J\42WZ4,6M54VF>SMAI[G4:P[4'F-U]W)H!
MZ33%Q]9!8V=G1TB<0KV+OB276.ZN]2YK6P=?/M[9/ZS(23!G;\?$O-$7&$_U
M8I!:L1HR/X,TOV1!LI7PA#[^AT?OTE^5ZP=.*$E*D'&.D,%)]8S<^FS7F^E0
M-(EV'S]*SQ4;*:KP^JN%JF)3C[[:;F'7%7+%YUDG!(H3"K_DYKFTN+.?#H7`
M1S9]WBTRF].$+-.Q7>]\8PN^DY3&HT>/W1`>6V6H'VR%!M:O!.]HD(7@<8(&
M[\CV^B@=_LTV"!"TINTL3^N[3>FNM+WA2.J2J,AD#(B!1G:AXB53]0;YWY@G
M^O+RL["S00G<4G,RXU9*C?R2=J0^_.6J8NHB8*T'2E!:P_U;QJUR4;J*T>>2
M+]O8"PH#BEK15+D/)6@J-RH-O$QGJ"S_BKB%GG>%ASVQURWSS&E@=9!]5*LU
M#5IW$BBUFL!D>5VV`1)K>%&-2Q=:LJA95SH^BUC)-:<[$RA^"5\4:B<EEFC(
MRR,XK>(-@?:]^5Y8P6[ZK$17@E7]P/[1PJ#,]8T[C?\<Q?\>S";H5+4^F)W?
M71_+XW]CS&^._[ZWVWC\Z%$3DB!E'?_[3_GN.0]H!H7^V^R&%S!PXWKAM6\=
M73L,6FTV,$CCG<36OHO0VI=%UC8;-XFK?8.PVN;V4;7-[8-JFU5C:IN-.XFH
M;:X=4)L[7#V<MKE9-&U!SZ6AM+'`*H&T=;U;A=&^DRC:-,S;QM"6Z;IM`.T[
MB)]]^_#9JT3/QL%?*W:V#=M;%3I[Y<C99@DF5@3.-NY_R%:$]P<]0BAF)LJD
MJ#,;QM<><?@*30<&]UF/;@4.G\OU'MA(N<W&0W&U<#R<R2!0MP7;+7RMA9%#
ME3+X8,/]?#:>_L[!H2M(Y])W3YWD$L^Z+KU3NQSHI&@L-N25!1.,R(E^Y_&I
M9@9M.#OL_(R!C$O8W0I+GL@=,TSRU\V]G2:VX)6+@H(LYPZ_*O$H>F=)`O<M
MY+I%B3C)QJ*?<LE8M&D'T7HP&H\>AGI>?!8"&6SQ$PY^>%P:J#G#0(88N'EL
M^FD;+=!0LG;A!##F`:YT>MY&Y463'9.ME2$K%<)VBAANM=5U"(*'=?-LA"<U
M_1\.:MI+G0'<9>DYG358$UI@#*KOG-,NI@/#0`I%:N;W*$SPW@8S9-C*,B?V
M4Q[Z1;9BI,!)/+$>$O3YG_;&I&*)YYQSC.S51=C]+]Q]>#4EHS%%>"S^3A6-
M:'=P`P_RA]_%4BG4-R$ENO?ESCZH0'RMI#L>]&=$AO53>EE((CPJARK9M$Z)
M31$69-TQCD^#.?07MS"8=ZR?</4WSX#70./!>@>OKCFS[56[A>C!!UL:=GF6
M8/1-A$M7;27'V32?<9(PMF2X%85Q7KDYR@QW`GI8'[=G@`1=TI1M);W.($QB
MZ+2_0?:,2]Q`/)HLCPX&'>KFD#X.6P0`+I/OVCQ0P6&%9:^OW)Z?A[M,IE.Q
M)!4[$IYB(]A/J*T`9^_\7#<3EQ76I904N;G&$]@J:#*<6.D+C?%DT$E0;$J3
M*EX(S3UZ(W<I!D;?D#5F&]".KJ\Z\8YYR\A<ZXBBX7E$VJE5VXMA)UDVYWQL
MU0\`>"MP*N_+X/3A^J4X:4$%.+(JZO!4P']#0&%WHAE=GG8M0U.6=IIZQH=?
M6.KNV>PY(MD+.2,$9<?'8_9IR_$+[`F"[K1X1GK9D+P]0W=/&OG$,O(DR6`2
MT^V!^UQ85SBN)Q3S@?^(1''E[O#8\$Q1/K4H["ZB6I@9-84EZ$PK:VQ0/MU$
MKI"WL;(@>V4@58VTRM&YU60*SW<Q%8*_VT.HW!WV\G!`M"9V.&KF%1Q*B8@&
M&!AZB'88WTIXP13W(M^L_D['Z\OKE^$;84[76N="NV%W2"%V>B;H/:'+D%7F
M4&B2\_C:T\[XG&Q-R`ZPE?>S"9)(K5/D'LI%C,QDE"#CO]*XG*JN\Y)'-Y5S
M6?7E#QD197^/S\+?,)J70"F^\^V.6=X(SAQ!\;V<8\+U=_;I#G]5AC@@Q8,,
MKC54WG79Q'[6AQ;?-'DFZN+P>]SKL1MQ4EQF#^;]%!\:L-J]'O[ADU$%F9+Q
M#R7QMOD2L0,*8!?\RQ\N<?-(U^)?&W$SW`UFXU^EYC$C;M\=1,8H<4)TN-XK
M?:H`GW.7E"%$I?O(Z`U*R2)>BY.MQ9#/J6Y:>V*'->!`[)<F#+)A-K-Z6O:4
M.A6/$Z=<%LX^/37#,5PH^#Y1<\@;QGCU/I@Q-)A@UN?XO"T%9N,6KA"_;Y1:
M:NL4SBO_"X7+TR1BJ<O$4IY.[G>2\UGB7T>%0PDE^Y,F8>?H1KW21V^B8?4*
M\<$@;*+,"W9A'T^V*!]HOH]@.3"J[WBF7.17#;1RF)<,$IOS8Z@8HF2&H2KY
M16JBER9J'=FHD1/KY8JV"EV<*)2'(=*_BXT8]S8\,6(-*8">Z+=/,Z2OF;8B
MRS^3RE$R0!8A5OC8SWI0_CZQ(S0YD9M\#J1@.S<?VQT@BN'POH\5'(G0V),^
MD0U)M%F[:V.W>3"(9N>^X>J0N&!0":6`76BIKNE.V.KCP6G*(<8L\4)2GIZ`
MZSLG3AL23AQG4;@`2(,?9^<<<$]H+PHL"W6/YT#5$O'CJ%/S!G8UA]_.4A;B
M=U(DX++1*:I#G"!U7:_7B=ID[PT8SZ#6^.!">*/7`WQ<#F4/]\8Z15$\47@)
MPT<-7M_6E,?YFLF.^T-G`V3$BX'\4UD\@2>^"C?/<(6>#>!*Z3@P3:1GA5K8
MEIJ)0TL%A=A%!)G'^+VGLXIMZUO#[PP7B5H]276'"%;8F>H*,QV-9%NR]Z9,
M:$@#N1>W/"!<R"HOCG<-R+RIG/(R19UIH7YA3]I/20N9%[CU`=-^^N$7\_S5
MNXHK8OGGKL[L^'2<]90"+Z21X).F(S258K7L%;OB8Y-),YMDU\5>2QK-PC@8
M]K>>$DT-0XG7Y:4/"X3$,Q=6)),?H84`9P!NO0T+@?P.EW`T[$SUAD"'Z_Z$
MY:=^=Z;WD?PW#ZZ<PD==<:'L+#[8.Y8GCP7>`N]\U(_GE3V<F'C])'F;7R.6
MO1"G._PG`LFTSGKJNGP:UZV\-X,5L#9\OJ(I'-"VFI_\8``6(%F1D*P`PL(J
M>][;()[-U:K<ZJ,:2@Y*>N9PG,-9WDVG,V14R:V0>V;P1^:$WL=[ATYW5F$^
ME`J>J>V8Q7P'!,('BH\)&#3F()DLO^A10WDVXM"SYN.+M)NB^M)]>X&8!W1M
M6L77-C&U%>^5^58DWD4A<F]V7B]]#_CN:SRDLG,X>;N_I[VO1>B\K.QL/![D
M7\_:G?F@/3V/6P_+GDS;DW[6S;^V?]2S47Y)6?K/D1;8479*DA\1]TV1W0\3
M/,CK-U]GQA0G<I?O_UH>^V=_D?S?FFKAJM]9'U?(_YN/=QLD_W^T@[H`CU'^
MO]=<R___E,^^GMEDB%5--!+<W\)\=OV"0AYWXO50$VT*AS&<7?!RO:BKA[B3
M1.7P].]:,>%9.DV_DU)R$!GS@!IDOGG^G>_[_D,LIF%K*RA$9,4%KJ.F<'L]
MA7NQ#@!W?A>:"G>BJG"IKH*:Q6MI*]Q$7>$N]!7N0F%A=8T%GIT[T%FX@=*"
M[7-UM86;ZBUPC_C_I:H+7&05Y86PYJW4%^Y&?T%&>UL-!C]QMU5BN`LMACM0
M8UA)CX%GX%J:#/:,KE1E6%V782EF5B@S^'5[_?.+5S^^.GSV#F%]]N(?&M,%
M/<X`^G@)I*DM/++@[XZX.$5*C$P0)_;@P0E3U]R#_"%CTQF\;_MTX,&#7/0[
M>K"'_YYC`PX'Z.!&-,!K@980VWZ0I=`.8@9-V(4LE&3\A>&CDS0=Y7.^GNP:
MA[=+;H\7M)U$KJUU6PO7VHA&+RC#ZS-*SQQ9(1<$Y(YZ[6G/WA"&ED%,:8E:
M81@<CBH8T+C3SPV`DN8"C&`)7F6NJ-LO;EYQ8GB3X/WO(`D6&:'IM@ES1P8`
MSVB+.;2KF)&.*H!"%.G-P8'S/B5=XYY=Z7B9M\RL_3M>#5W$QQF=_^..WY7A
MIG)[J;QRO&QCRY&$6Q%>'SB<O'V<PDC0R71Y",'@J35:"#P+M#H151R?X7-B
MGJ%0^8)F$VXD)+SL><6'PF@V'?/)*HLCNU,=D-2<FH2_^'U"RB2,$M@4TKRV
M<V,EB+E3'Q)"V.-!OH5HP0LQSE-[$+D%=^#FZD'#J)%7K`X[]Z6C`LV<1J;=
M`=0/CH6-UD]X<,+;YT=ZJ17R#EJ\Q_<C*R1]V&B]X1,TM][6[?,4;07>6QI[
M9]^<-NK?DG7BD059Z'L1C_)T3K@5\^#'U]G##\0J#ZUVZ6:_"X-+>B'<@;TE
MM7,-<TLJ=PMK2^YG=6-+JG\+6TNNO[JI);]`5[>TI/JW,+3D^5_=SE+Z7]G,
MDNK?PLJ2ZM_"R#+J?ZF-)5.@LJ/)L.(^'IIXTM*CB'=N,PUIRP>'#X&6_.;;
M;=SUYD=X\?P."PY7Z:#3[O:WZ%W*/KM)Z0XN@EY][<-J[<-J[</J/\2'E7L:
MK!U9K1U9_4&.K)89"`9<VVM;"7K^OQ/.W#F/V>SM/-[?OXS_SS^$___X\?X>
MB@3V'^W_E]F_<T@JOO]P_G_%^O=.LTGON`Y(>4=]7"'_:>PT]]WZ[^Z2_.?1
M;G,M__DSOBKYCT>`/TKZ,\V0_U<M`>+>MTB3K;$UR=$/??Y/+P_2E>/G^;=[
MC%,OVD"UF\,VJE_`B([23AOH'2"`WK;[,Z%J_5=J141'82L;:JJJ!"D1Y?_Q
MI>PG\WP^Z@W2^W:*7LV4'SK-Y]Z<CYB3V=L4IG#,]W9LHD"3P&Y<TZ&.ZL9Y
M6]O9P7?K,"61N?!ED)%&2BG(L3KF9@-FN(7SV17,6K$74B/8(CE.9L>'C41#
MY)&83<?^W&0&KV'O5#T9V!"5G3M$@`43%,T(L[+3&?/0U>QIT8B,,QZ@X^R@
MJX'"8[SWR/7>6J8UFN9TM[[3,R\(\[9[Z03N8>09TSP\>/'F<.OHS?^\??A!
M7-HDJ(/9GIZX!PO&OT`'`10Z00P,./$)*FWQGV0V0)$RK%ZU+_;4!78+7)'1
M'ED4SZ8GK(,/3Y#[Q%\%S)@23_S]SE;C`SJ([_<"VH7U1`%S+OQCUL%=B`$:
M^3J`06`Q(VE!_>[P@B.02UU.:+:2!&.IJLF0DENUYE9M=ZNVAR7V2[WN+>*4
M1BFE64K95;#N%]B107<035/;-=)D`/3TI!/`C+^K0*9R##'F[I7`O2EP>P4T
MZ6`K`_;VY?,`,/Q=!1B5BP"3/,A"N#EL'OF:*&<U):M3SMJ5K*[+PG1I:4NJ
MR;]=ZEL/0K?EL2I"?C$P$Y1/NMW!J9N@)KMOFB23F118!!/4S\.5P]]5$T3E
M[G;EH,DE*T=,]0`T3FEN;56`)Z5+``8>7*#AQ!'V1>6V_[NS>J($VOV\U:E:
M86$W5FDP`&,V3B8Y#0E`<)Y,.&^2!^Y,8-2M)`EJ4PFI"[?=BZR+!S9:`4`R
M5(P+$TI@8<C.TQG\Y$%$Q6CE?#'X65F,3Q-?#G]7%N0#SA?$W[8,>R)-J%YA
MG@^4\\W4)D?FGI:,AKOB._/U(2*,;H7=J3UY$E0*OX4R"Q*C$@VX2G%AG#40
MMN.G3\U"`8MZQ5?6>OXR`M>VP%B4Q*A<HNN1NV+1A+!3\;&2T2@;6/\]V:@[
MF/?2)$4$H]-IB(%03]+B2:WQ5*AK9["E_.E\L5!'!K:33--_)\[>E=.SK-[H
M3.Z5#Q.;37L)&X2$MFO%6SE(+5]$552+_.8(K_>#+VN-+X,`:X/!^0&U"G]$
M&1<VXR+(F$^E!OP195S8C+`&,0XQ(^^V!^FY"]B%C(7I679@/=C)R%E)W3L#
M#6I?A+7[OK:?@7(#6+T[@`<^_L<Q35+M4=NM<V<XL4^=\D)'B^F7P=HC<P'3
MN=BVDV<ZA!BL:RXS#6GL:BMJ2:D\RXM))AHJ>.?30=9%D%7>UR_?/GOS5V.\
MW\#(3.&2TL9.:X"W)G<V"-8RX%:-7<4CC.N)8;E`0?'*9?6FXUF"M"]J24=@
MO/WYG>$"%#!'W$0^>6*"RAB?K**B.IM>$@)*+U'1(V.S94^XWQ<5_7%.18]'
M$OTPZ!;&_N8HF;;/T+[5E0?BTO,5;1FVJ.SI@E^6BP&)B^'NDCY%_\3"UK3X
M-/,5OZ"*84T\0ZZHQKD'4I=/X/2XH!4$VC>I#V'UH'(!^VQ1U#L=$OA4%_UM
M<G+=HEBDJJ@%/CV?H4TD$.5%'4[RK3K^'_ZHGWS"O^D?_/G/ZN8G.;4.):!U
M_,^E@*1!T71IV<DG511A_G@R'WU"(X6N6=8!0!ET<>VZ4=6;U3SYM%K5-*Y[
M`X@W?36[C'8^E[J7\SR?._8PM_[^/W^>_\N&'']$'ROP_QO--?__3_GB]7>&
M/'=H`'*5_<<CQ?]O[C2(_]]8VW_\*5\5_U_CP!\D`=#V8F41@.C)>9Z_UUJ/
M=-4#;GQL(<):BUXWT*D*?B1<OR\,<V?;X8TA-`,Y,/6P>K@L+F"+"V>K$:H!
ME[26D3&K-..=9F^LM7Q=+?KLF/C>I-2>D2XRZRJ7&.X,]!1-),?D-B1<%S9J
M+\]+Y<#)3UIDK:*U72N4,0F#`GL6)96H!);`*$$!-;\+$:<DN&FP=E8DN+E,
MU;.LWFE;UU$\G)IG\Y$Y;=9W]OP&N>\U.E^\.43^_PO2VT]_YKBNJ"R""J@+
M?/C#<^OG8^FHA:X,8"I]?U'-7HKV(M>L^H;=1G'5?*/U-OWW/)NF=E!H*',A
M>JVHK;K[047E?O<K,GZ$QQ(DCP<]<4152L;0VD$B'*$GZ2Q,ZZ6#65NYD^>>
M<A],`!*8VK!#(28".UB&O**5,+OJ-)L*0Y/T+'8./BZ$E'8]VS`Z-E',?]]1
MIJ'!(?&'OOQ1K\W5X]A![%JO6&`Z)":=<>]B(:[GX,ULP;/NUIW#/U6<F6$$
M9-FCGW??AWQYJ'6<C7J)YY*J%*WC(DPQRZTF[U#,R8$*`6<.?BLX+9.A#(DP
MDQTX%&(<:8.X-3LL+S#"!5$H)TFJUS*_$/)I\0?19$@%]@]7!!BX\!Y'4*L)
M\TXYYAG/"*"4]EEUVA[,V9TWC4G]5*[5+#YU?Y^@V_)!0G_YCK#1`'L<XA\X
MD9SD.#@/%-)[533!\`/TZ!!B8N*TG<A(W9"RM_F%'.+9-`XU'R7^*LFBDX0M
M3I%G0-/QTV$R3<FI7/)KI6Z<9;$)8`@75D)D,Y-XYF5&QF/1=X)<]"#2MSI6
MN%UM!@.Q$/VR2=J>;=B`KHF-*8NN90BU9Q1OES//;>Y(<L\EFYL6]K*@R&:`
M3I[9'"&96P=JPB%WT*)'U,W83;M?/``E1%7U8V$/#BBT856^X"@J/&\TA#5L
M"2HN_+:A>2WLBCI_=LRD##%0>UEPTQ_BH3V1W>((SA5OTW:W#_<JNAX9SH=\
M#FZ9#MP+>(W/)W+\>=U3YL56]1IQ:[>CB8^$VN[XET6I@DJ?P"%;5#1*!6N?
MRG:2O`BGR0/<T)=03.Q`.D#E[!44->5+;(?WH0.''%Y(L:<FX!W++?L+^Q#U
M9V0@.BK</L:WC1G!E3P^,P\X=ABF0'_IP]9KYIX_1W<FVG&5!HJ.710#RD\5
M?#'F+7O<.*@:5^FT*ZUZ&=^V91:";!76QCGJL.Y,U%WA@2X:Z1`R+)8<M/K'
M\T^?Y*U`_D0!68I?7:B*\,J`"V"B>)7NFBFD?@(UW^]\\-ET6MF;-?9*=J"=
MINAW1.5A1DW9,P!+X`V%_F.5V\QE*LEN*.6C3JME+VU"/TF6'6_4$%9V'D@/
MQ&\ES@O=&W!7UFI%P4+)=IYG)^1V:\$GZ('=F_U.NS<"W(2;[36O57`U2C>J
M%"D(C&9M3N<*3MHD^[T\*?'9[4?E;C^\NJ.KU=VJ5E@3W@[M`0S*HRL%X%-X
M+J*OR_Z;)-=N-=BDUVQ5(%?U<WU-8">U1KW6K.W6]FK[M4>UQ[5O:M^B//N>
MNX1JC2>-':-%>"K]DHQ6,KPD_;5.+_6M1V$USI&ZZ%A[('X#M&"U*;UK!=L1
MT>(?N>JU'AVE/XW_ALZ8W8&ZJ*B3T&O0-O#`EGV(GDQ)FB);5$KX0%YA>N(S
MX`A!#+0W??#8EZ>*,_30D6#\Z\`K?NO#HU)N]YZM;*SJ!:S*Y'CD-_"'*Q\H
MGD3`Z0F`M0\K]!-GI?E+6E+P:[#)RURMR7.I6G?G($S&8J-HS<5T8_/@8\L`
M)',T822;#38'D(=\(:]N%XEJ-!\,W!E:HO%:LYD$!".L"AP];;#&#'+O".D^
M;U([&/>(_UVHG73:L:%*><;PW&L(J<8$0VDQO;OU\NX_;0W3-N*H)<A:!J'3
M3T*K?_6%`J+6^*)TU%(&>5<4EZ18Z<"$\5B]N<SF@?^[IM)K&(W,3S4U:,\(
M.V89BP^;Q#.5U.)7H`.$";#$OO#L:&D!/C.-*4G:>QE772APDLV&V6RZ!^]I
MTH>C8A.N'KF/LN/-)DP@-OBY--<)-+O9#)JSU:'-S082QE"=6\(F:N4FL()M
MQAF&N75!W!,5+'$%7_A-C&AK=5WG(^@EHT=;1NYB3?#<TYZ/HW?!%=*W@..Z
MEK^MO_6W_M;?^EM_ZV_]K;_UM_[6W_I;?^MO_:V_];?^UM_Z6W_K;_VMO_6W
=_M;?^EM_ZV_]K;_UM_[6W_J[\OM?%_$CS0`8`0"_
`
end
